#
# spec file for package python-jenkinsapi
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-jenkinsapi
Version:        0.3.13
Release:        1.3
Summary:        A Python API for accessing resources on a Jenkins continuous integration server
License:        MIT
URL:            https://github.com/salimfadhley/jenkinsapi
Source:         https://files.pythonhosted.org/packages/source/j/jenkinsapi/jenkinsapi-%{version}.tar.gz
# https://github.com/pycontribs/jenkinsapi/issues/819
Patch0:         python-jenkinsapi-no-mock.patch
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pytz >= 2014.4
Requires:       python-requests >= 2.3.0
Requires:       python-six >= 1.10.0
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module astroid >= 1.4.8}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests-kerberos}
BuildRequires:  %{python_module six}
# /SECTION
%python_subpackages

%description
Jenkins is a continuous integration system.

Jenkins (and its predecessor Hudson) are projects for automating
common development tasks (e.g. unit testing, production batches), but
they are somewhat Java-centric. The designers have provided a REST
interface. This library wraps up that interface as more conventional
Python objects.

This library can help to:

 * Query the test-results of a completed build
 * Get a objects representing the latest builds of a job
 * Search for artefacts by simple criteria
 * Block until jobs are complete
 * Install artefacts to custom-specified directory structures

and has

 * username/password auth support for jenkins instances with auth turned on
 * Ability to search for builds by subversion revision
 * Ability to add/remove/query Jenkins slaves
 * Ability to add/remove/modify Jenkins views

%prep
%autosetup -p1 -n jenkinsapi-%{version}
rm pyproject.toml # Just utterly broken

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/jenkins_invoke
%python_clone -a %{buildroot}%{_bindir}/jenkinsapi_version
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%{python_install_alternative jenkins_invoke jenkinsapi_version}

%postun
%python_uninstall_alternative jenkins_invoke

%check
# jenkinsapi_tests/unittests/test_view.py
# E       fixture '_view_poll' not found
# jddenkinsapi_tests/unittests/test_plugins.py
# E           ConnectionError: HTTPSConnectionPool(host='updates.jenkins.io...
%pytest jenkinsapi_tests/unittests jenkinsapi_tests/test_utils -k 'not (test_view or test_plugins)'

%files %{python_files}
%doc README.rst
%license license.txt
%python_alternative %{_bindir}/jenkins_invoke
%python_alternative %{_bindir}/jenkinsapi_version
%{python_sitelib}/jenkinsapi
%{python_sitelib}/jenkinsapi_tests
%{python_sitelib}/jenkinsapi-%{version}-*-info

%changelog
* Tue Jun 27 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.3.13:
  * Unable to locate upstream changelog.
- Re-add missing BuildRequires on six.
- Stop using greedy globs in %%files.
- Rebase python-jenkinsapi-no-mock.patch
- Add missing Requires on update-alternatives
- Switch to autosetup
* Tue May  3 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches
  fix https://github.com/pycontribs/jenkinsapi/issues/819
  + python-jenkinsapi-no-mock.patch
* Fri Apr 17 2020 pgajdos@suse.com
- use pytest -k instead of removing tests
* Thu Apr 16 2020 pgajdos@suse.com
- version update to 0.3.11
  0.3.11
  - -----
  * jobs.py: don't yield jobs twice (#740)
  * Add debug log message in JenkinsBase.process\_job\_folder to follow execution progress (#738)
  * don't faile when node\_descriprion is missing (#737)
  * Fix safe exit test (#736)
  * don't stale feature requests or "help wanted"
  * change label for stale issues
  * Fixed idle state not being refreshed (#575)
  * Simple plugins (#735)
  0.3.10
  - -----
  * Add method for streaming build logs (#722)
  * add instructions for Stale bot
  * Fixed problems with changeSets (#717)
  * Create Node by providing predetermined configuration (#730)
  * Fix plugin versions (#734)
  * Updates Requester to use a Session, maintaining cookies (#727)
  * Feature/multibranch pipeline job (#715)
  * Fix failures caused by plugins (#718)
  * Fix for build.get\_artifacts() (#712)
  * Add safe exit (#700)
  * simplify crumb usage (#704)
  * generate new api token for logged in user (#706)
  * ignore dot files (#705)
* Fri May 17 2019 Hardik Italia <hitalia@suse.com>
- update to 3.0.9:
  * Updated password
  * url encode folder name, to fix forward slashes (#702)
  * Add new method to create job and use it to speedup QueueItem (#699)
  * See if Jenkins is lazy when loading build history (#698)
  * Removed python 3.4 and added 3.7 (#695)
  * Proposed CloudBees integration fix to job.invoke. (#693)
  * Fix pylint errors (#694)
  * Add authentication system tests (#686)
  * Use session id cookie to improve performace (#685)
  * Parameterize war-filename and locally save hpi-files (#684)
* Tue Feb  5 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description and fix grammar issues.
* Tue Feb  5 2019 Thomas Bechtold <tbechtold@suse.com>
- update to 0.3.8:
  * Fixed typos noticed when reading the file. (#680)
  * Support keyworded variables for requester, fixes #679 (#682)
  * re-encrypt password
  * change password again
  * Plugin delete (#674)
  * disable pyling check of unnecessary-pass
  * Updated pypi password
  * set travis to release on tag
  * Add future improvement line
  * add dependency plugin: trilead-api
  * Removed unused files
  * add try except for func create (#675)
  * Removed unused file
  * Skip test on release stage
  * Add method to update offline reason for a node. (#613)
  * Support SSH credential update (#619)
  * add ability to keep build forever (#672)
  * Handle changesets returned by Jenkins job that use Pipeline (#654)
  * Change pylint command line (#671)
  * update README dev guide (#667)
  * Fix a lot of warnings (#662)
  * Remove ssh credentials no longer supported by ssh credentials plugin (#657)
  * Update link to travis
  * Expanded test coverage for view.py (#646)
  * Python 3.6 and 3.7 support (#641)
  * changed requirements to support 3.6 and immediate testing
  * Changing to  \*args and \*\*kwargs in requester init. Fixing TypeError bug (#640)
  * Retrieve git repo url for a given build (#634)
  * Get Build url for a given build object (#635)
  * Add support for client side certificates, closes #632
  * add View.remove\_job
  * Add new method Jenkins.run\_groovy\_script(self, script) for running
    arbitrary groovy scripts on the Jenkins server. This fixes #601
  * Add additional methods Nodes.items(), Nodes.itervalues() and
    Nodes.values() to match the methods provided by the built in dict class
  * Add docstrings for Nodes.keys(), Nodes.iterkeys() and Nodes.iteritems()
  * Added a tests for Nodes.iterkeys(), Nodes.keys() and Nodes.iteritems()
  * Move common Node creation functionality out of Nodes.iteritems
    and Nodes.\_\_getitem\_\_ and in to its own private \_make\_node function
  * Added methods to Node for querying information stored in the monitors
    section of the api tree. These allow the querying of:  - The node's
    available and total physical memory.  - The node's available and total
    swap space.  - The local path of the node's workspace area.  - The size
    of the node's workspace area.  - The local path of the node's temporary
    area.  - The size of the node's temporary area.  - The node's architecture
    (eg. "Linux").  - The node's average response time.  - The clock
    difference between the node and the Jenkins master
  * update xml version
  * ignore not relevant pylint checks
  * add QueueItem.is\_queued() and test for it
  * Small Nodes refactoring
  * Fix arguments passed in how\_to/use\_crumbs.py
  * typo
  * Add link to full docs in README
  * backwards compatible get\_credentials
  * Fix pylint errors
  * Fetch, update or create credentials by id instead of description
  * init QueueItem properly
  * fix inconsistent return values
  * update examples information and add example for CrumbRequestor
  * add release to pypi from Travis
  * don't check for redefined built-ins
  * fix lint
  * converted tests to pytest
  * add missing imports and fix code formatting
  * Add jsonp\_to\_json module docstring
  * Move Manifest parsing code to utils/manifest.py
  * Add unittests for installed plugin version
  * Fix Plugin Manifest parsing, plugin install status
  * Add 500 to allowed status codes while restarting
  * Move update\_center\_dict handling to Plugins class, hopefully
    fix wrong version issues by restarting after install
  * Optimize \_wait\_for\_reboot
  * Lint fixes and decode bytestring
  * Add plugin uninstall; install exact versions
  * Fix credentials update test
  * Credentials update support
  * disable master executors temporary to let test pass
  * add codecov dependency and env variables for it
  * add timeout parameter to Jenkins object
  * Fixes pycontribs/jenkinsapi#530. It's possible for queued tasks to
    be unnamed. This is the case when using Pipeline jobs. Check that
    tasks have names before referring to it
  * Close #583: Handle parameters with secret values
  * disable logging from requests
  * reset executors to test queue
  * remove encode to utf when posting config.xml
  * add new plugin dependencies, fix all tests
  * change disabled job detection (#543)
  * Add support for AWS Credentials (#572)
  * Fix bug when using private key file(on master) to create ssh
    credential. (#573)
  * Added missing plugin and changed wait for restart test (#579)
  * Enabled 5 retries at request lib level
  * Add missing packages from package
  * Add Jenkins pipeline linter
  * Adopt pbr
  * Dropped support for Jenkins 1.x
  * EnvInject v2.0 now has security settings - add this
  * Select jdk8 for build
  * set java version to use in Travis
  * fix security settings json
  * fix: linting (#561)
  * Add estimated duration accessor to build class (#555)
  * Increment version
  * fix security json for 2.x Jenkins (#541)
  * Add support for jobs in folders
  * Remove .tags
  * Update test case for node management
  * Enable config Tool Locations for jenkins node
  * fix spelling of artefact to artifact
  * Correct typo (#531)
  * Add get\_env\_vars to Build
  * Close #522 Only use parameter actions to access parameters. (#524)
  * Add ability in Node to upload a config xml (#515)
  * Allow fn changes on save (#518)
  * Fix source code url. (#521)
  * fix up tox (#523)
  * Update index.rst
  * Migrate to six (#507)
  * Set to use latest pylint
  * Removed test
  * Converted test\_job\_folders
  * Converted most of the tests to pytest (#508)
  * Changes based on code review
  * Added codecov library
  * Changed call to codecov
  * Removed "isinstance() is True"
  * Moved unit test to systest
  * Partially converted to pytest
  * Added asserts for file creation
  * Removed unittest that is covered by systest
  * Converted test\_job
  * Converter test\_requester.py
  * Converted test\_nodes
  * Converted test\_node
  * Converted test\_misc
  * Deleted unused and duplicated tests, converted test\_label
  * Converted to pytest
  * Renamed all one letter variables
  * Minor change to make pylint happier
  * Fixed identation
  * Converted new tests after merge from master
  * Fixed failing test
  * Converted test\_job.py to pytest
  * Converted test\_jenkins.py to pytest
  * Fixed import
  * Converted test\_executors to pytest
  * Converter test\_build\_scm\_git to pytest
  * Converter test\_job and moved job/build configs to separate file
  * Fixed problematic merge
  * Made pylint happier
  * Fixed tests for py 3.x
  * Ignore temp folder removal errors
  * Fixed launcher
  * Added thread.stop
  * Added Jenkins plugin
  * Removed python 3.3, added 3.5
  * Renamed exception
  * Converted systests to pytest
- Convert to singlespec
- Add license.txt file
* Fri Nov 18 2016 tbechtold@suse.com
- update to 0.3.3:
  * Fixed for Credentials 2.x plugin (#460)
  * Added tests for adding jobs to view (#469)
  * Return full response object if requested on job.update_config method.
  * Adding SSL disabling option, authentication, correction of Java Heap
    setting and some very helpful comments
  * Fixed failing tests on Jenkins 2.0 (#473)
  * Delete build (#493)
  * Decoding bytes with the ISO-8859-1 encoding
  * Removed pypi upload
  * Added coveralls integration
  * When job is invoked with file param http headers will be now set (#494)
  * Adding newline at end of file
  * Adding a note about using an API token as password
  * KrbRequester.get_request_dict missing **kwargs
  * Update setup.cfg to support universal wheels
  * Set version to 0.3.00 and cleaned up a bit
  * Add ssl_verify flag to the Jenkins class
  * Changed jenkins launcher to use pre-built home dir
  * Proper handling of self.url
  * Added SSH node creation and tests
  * Adds correct build information to Build.get_artifacts
  * FIX: allow jenkinsapi to be used without installation
  * And exit 1...
  * working tox configuration for testing/lint with multiple python versions
  * How to kick-off a paramterized build (eg build version, python version)
  * FIX: fix bad indentation (2->4 spaces)
  * Fixed EMPTY_JOB config to match the one returned from Jenkins
  * Now using either wget or curl to download the jenkins.war
  * Fix pylint violations.
  * Revert "Get rid of unused modules and unhelpful comments"
  * Correct the logging format
  * Fix for issue #357
  * Can't find job parameters if in 'property'
  * Restored old way of finding jobs (#477)
  * Fix line spacing
  * Added how_to examples for nodes and credential creation
  * Get rid of unused modules and unhelpful comments
  * pe8, flakes, system-test for safe_restart
  * Fixed pylint errors
  * Added tests for issue #487 (#490)
  * Prepare chunks that are applicable to both Python 2 and 3.
  * Fix 'get_build_by_params' method (#506)
  * adding jenkins.install_plugin, jenkins.install_plugins, and jenkins.safe_restart
  * Removed UTF-8 as a method of decoding the content bytes
  * Categorized view plugin support and change View#add_job approach (#468)
  * Version 0.30.1
  * catch ConnectionError as well as HTTPError while waiting for restart
  * fix typos and lint
  * Version bump prior to release
  * Implement `Secret text` credential (#504)
  * Unified node creation and fixed tests
  * Fix job search (#465)
  * Update setup.py classifiers
  * download artifacts: handle files with special characters
  * Add unit tests of artifact strict validation.
  * In systests.TestNodes.test_get_node_labels make sure the node creation
    code matches the other tests and cleanup the created node when the test
    finishes. Calling jenkins.create_node instead of
    jenkins.nodes.create_node might be the cause of the Travis CI build break.
  * Do not ignore tree parameter to poll
  * [doc] pep8 cleanup of examples in using_jenkinsapi.rst
  * Added required plugins
  * Added codecov, removed coveralls
  * Added issue template
  * Added note that library is not tested on Jenkins 2.0
  * Add Build.get_description()
  * Add ability to retrieve build by params (#488)
  * Cleaned up examples and added example of running job via invoke
  * Update using_jenkinsapi.rst
  * Incremented version
  * Add function to node for querying the labels from the node's config.xml.
    The config.xml querying and caching was copied from the job's config handling code.
  * Job object now able to find job url by asking server
  * Fixed get_config() for jobs returned from view (#478)
  * Moved unit tests to systests
  * Normalized version
  * Manual PEP8 changes
  * Delegated all job operations to Jobs object
  * Fixed url for latest Jenkins version
  * Optimizations to reduce amount of data requested from Jenkins
  * FIX: No longer remove JENKINS_HOME folder when JENKINS_URL is set
  * Add the relative path for artifacts (#497)
  * Fixes #446 and adds check for credential existance before deleting it
  * Fixed broken link in cancel item from queue.
  * Add changes to get slave information
  * Changed all links to point to pycontribs
  * Add a doc regarding ssl_verify arg in the Jenkins class
  * remove testcase which is no longer necessary
  * Added systests for stable and latest Jenkins version
  * Should be echo, not error
  * Fix coding style violations.
  * pyflakes
  * To parameterize the level of fingerprint validation.
  * Added PYPI deploy from travis on new tags
  * Added get_changeset_items() method
  * negotiating python 2 vs 3 differences
  * Moved some unit tests to systests
  * Fix for broken build.stop() function with Jenkins 2.x (#464)
  * fixed python3 compatability
  * Strict artefact systest (#480)
  * Added check for missing "firstBuild" item (#482)
  * Add sudo: false which means we use the new Travis infrastructure
  * Add a warnning message if fingerprints aren't enabled
  * Add support for retrieve info for Label (#459)
  * Added section about Jenkins versions, removed "not tested on Jenkins 2.0"
  * tests for install_plugin and install_plugins
  * add utf8 encoding to support invoking jobs with unicode build params (#500)
  * Added credentials and ssh node creation
  * Make parameterized builds with file params work
  * Added more information about library capabilities
  * Set Jenkins obj to ask server for limited info
  * Added better example for views and fixed bug
  * add tox to gitignore
  * J2x insecure start (#449)
  * Tidy up __init__ and comments
  * Revert "Add sudo: false which means we use the new Travis infrastructure"
  * Changed poll: do not delegate to parent class
  * Added support for ssh credentials
  * Set Jenkins download url to use LTS releases
  * Added CrumbRequester (#479)
  * handle python3 urllib
  * Changes badge and cleaned up TODO
  * Revert "Tidy up __init__ and comments"
  * Adding a why property to a queueitem object (#456)
  * fixing lint
* Wed May  6 2015 benoit.monin@gmx.fr
- update to version 0.2.28:
  * no changelog available
- remove python-nose from build dependency: not needed anymore
- add python-pytz and python-requests as build dependencies
  to ensure their availability
- increase required versions of python-pytz and python-requests
- add jenkinsapi_version binary to the package files
* Fri Jul 11 2014 jw@owncloud.com
- Version bump to 0.2.20
  commit 326b370d084b83ad780569e28dd5ffad908936d1
* Mon Oct 21 2013 speilicke@suse.com
- Initial version
